==> on_audio_edit-1.0.2.tar.gz: CHANGELOG.md <==
## [1.0.2] - [04.20.2021]
### Features
#### Dart/Kotlin
- Added `[deleteArtwork]`, `[deleteArtworks]` and `[deleteAudio]` **[Currently only on Android 9 or below.]**.
- Added `[BITRATE]`, `[FORMAT]`, `[SAMPLE_RATE]`, `[CHANNELS]`, `[COVER_ART]`, `[TYPE]`, `[FIRST_ARTWORK]` to `[TagType]` and `[AudiosTagModel]`.

### Fixes
#### Kotlin
- Some fixes

### Changes
#### Dart/Kotlin
- Changed `[TagsType]` to `[TagType]`.
- Removed `[ID]` from `[TagType]`.

### Documentation
- Updated `README` documentation.

## [1.0.0] - [04.18.2021]
### Release

- `[on_audio_edit]` release.

## [0.2.0] - [04.16.2021]
### Features
#### Dart/Kotlin
- Added `[editArtwork]` and `[editAllAudio]`.
- Added `[resetComplexPermission]`.
- Added `[getImagePath]`.
- Added `[LENGTH]` to `[TagsType]`.

### Fixes
#### Kotlin
- Some fixes

### Documentation
- Updated `README` documentation.

## [0.1.5] - [04.13.2021]
### Features
#### Dart/Kotlin
- Added `[editAudio]`, `[editAudios]`, `[readSingleAudioTag]` and `[readSpecificsAudioTags]`.
- Added `[editAudio]` and `[editAudios]`.
- Added `[permissionsStatus]`, `[complexPermissionStatus]` and `[requestComplexPermission]`.
- Added `[TagsType]`.

#### Extra
- Now supports `[Android 10]` and above.

### Documentation
- Updated `README` documentation.
- Updated `pubspec.yaml`.
- Created `README` translation section.
- Created `README` translation for `pt-BR` [Portuguese].

## [0.0.1] - [04.12.2021]
### Features
#### Dart/Kotlin
- Created the base for the plugin.

<!-- 
## [Version] - [Date]
### Features
- TODO

### Fixes
- TODO

### Documentation
- TODO

### Changes
- TODO

### Important Changes
- TODO
 -->

==> on_audio_edit-1.1.0.tar.gz: CHANGELOG.md <==
## [1.1.0] - [10.20.2021]
### Features
#### Dart
- **[Added]** `getMap` to `AudioModel`.
- **[Added]** a [`DART ANALYZER`](https://github.com/axel-op/dart-package-analyzer/) to `PULL_REQUEST` and `PUSH`.

### Documentation
- Updated `README` documentation.
- Updated dependences.
- Updated `OnAudioEdit` and `OnAudioEditExample` documentation to support new `[Flutter 2.5]`.
- Created `DEPRECATED` file/history.

### Changes
#### Dart
- Changed from `[AudiosTagModel]` to `[AudioModel]`.
- Removed `[IOS]` from `[pubspec]`.

### ⚠ Important Changes
#### Dart
- Deprecated `[AudiosTagModel]` from `[AudioModel]`.

## [1.0.2] - [04.20.2021]
### Features
#### Dart/Kotlin
- Added `[deleteArtwork]`, `[deleteArtworks]` and `[deleteAudio]` **[Currently only on Android 9 or below.]**.
- Added `[BITRATE]`, `[FORMAT]`, `[SAMPLE_RATE]`, `[CHANNELS]`, `[COVER_ART]`, `[TYPE]`, `[FIRST_ARTWORK]` to `[TagType]` and `[AudiosTagModel]`.

### Fixes
#### Kotlin
- Some fixes

### Changes
#### Dart/Kotlin
- Changed `[TagsType]` to `[TagType]`.
- Removed `[ID]` from `[TagType]`.

### Documentation
- Updated `README` documentation.

## [1.0.0] - [04.18.2021]
### Release

- `[on_audio_edit]` release.

## [0.2.0] - [04.16.2021]
### Features
#### Dart/Kotlin
- Added `[editArtwork]` and `[editAllAudio]`.
- Added `[resetComplexPermission]`.
- Added `[getImagePath]`.
- Added `[LENGTH]` to `[TagsType]`.

### Fixes
#### Kotlin
- Some fixes

### Documentation
- Updated `README` documentation.

## [0.1.5] - [04.13.2021]
### Features
#### Dart/Kotlin
- Added `[editAudio]`, `[editAudios]`, `[readSingleAudioTag]` and `[readSpecificsAudioTags]`.
- Added `[editAudio]` and `[editAudios]`.
- Added `[permissionsStatus]`, `[complexPermissionStatus]` and `[requestComplexPermission]`.
- Added `[TagsType]`.

#### Extra
- Now supports `[Android 10]` and above.

### Documentation
- Updated `README` documentation.
- Updated `pubspec.yaml`.
- Created `README` translation section.
- Created `README` translation for `pt-BR` [Portuguese].

## [0.0.1] - [04.12.2021]
### Features
#### Dart/Kotlin
- Created the base for the plugin.

<!-- 
## [Version] - [Date]
### Features
- TODO

### Fixes
- TODO

### Documentation
- TODO

### Changes
- TODO

### ⚠ Important Changes
#### @**Deprecated**
- TODO
 -->

<!-- 
 https://github.com/LucasPJS/on_audio_query/issues/
 - **[Added]** (Text)- [#Issue](Link)
 - **[Fixed]** (Text)- [#Issue](Link)
 - **[Changed]** (Text)- [#Issue](Link)
-->
